package com.iarkdata.bigdata;

import com.iarkdata.bigdata.common.PropertiesUtils;
import io.debezium.engine.ChangeEvent;
import io.debezium.engine.DebeziumEngine;
import io.debezium.engine.format.SimpleString;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.Properties;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class DebeziumOracle {
    private static final Logger log = LoggerFactory.getLogger(DebeziumOracle.class);

    public static void main(String[] args) {
        Long pid = ProcessHandle.current().pid();
        System.setProperty("PID", String.valueOf(pid));

        Properties props = PropertiesUtils.loadProperties("classpath:oracle-connector.properties");

        DebeziumEngine<ChangeEvent<String, String>> engine = DebeziumEngine.create(SimpleString.class)
                .using(props)
                .notifying((list, recordCommitter) -> {
                    list.forEach(event -> {
                        log.info("TEST-Record: {}", event);
                        try {
                            recordCommitter.markProcessed(event);
                        } catch (InterruptedException e) {
                            throw new RuntimeException(e);
                        }
                    });
                    recordCommitter.markBatchFinished();
                }).build();

        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            try {
                engine.close();
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }));

        ExecutorService executor = Executors.newSingleThreadExecutor();
        executor.execute(engine);
    }
}
